@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: EphyAboutModule.cpp 7075 2007-06-05 21:45:42Z diegoe $
+ *  $Id: EphyAboutModule.cpp 7202 2007-07-26 20:56:17Z reinouts $
  */
 
 #include "mozilla-config.h"
@@ -419,17 +419,15 @@ EphyAboutModule::GetErrorMessage(nsIURI *aURI,
 
 		/* Translators: %s is the hostname, like "www.example.com" */
 		*aTitle = g_markup_printf_escaped
-				(_("“%s” Denied Access to Port “%d”"),
-				 host.get(), port > 0 ? port : 80);
+				(_("Access Denied to Port “%d” of “%s”"),
+				 port > 0 ? port : 80, host.get());
 		/* Translators: %s is the hostname, like "www.example.com" */
 		*aPrimary = g_markup_printf_escaped
-				(_("“%s” denied access to port “%d”."),
-				 host.get(), port > 0 ? port : 80);
-		*aSecondary = g_strdup (_("The server dropped the connection "
-					  "before any data could be read."));
-		*aTertiary = _("The server may be busy or you may have a "
-			       "network connection problem. Try again later.");
-		*aLinkIntro = _("There may be an old version of the page you wanted:");
+				(_("Access denied to port “%d” of “%s”."),
+				 port > 0 ? port : 80, host.get());
+		*aSecondary = g_strdup (_("This address uses a network port which is "
+					  "normally used for purposes other than Web browsing."));
+		*aTertiary = _("The request has been cancelled for your protection.");
 	}
 	else if (strcmp (aError, "proxyResolveFailure") == 0 ||
 		 strcmp (aError, "proxyConnectFailure") == 0)
